# School.py

# -*-coding: utf-8 -*-

import untitleoop.Untitled
from untitleoop.Untitled import Student,SpecialStudent
from untitleoop.Untitled import *

def Test():
    '''
    ตัวอย่างการเขียนโปรแกรมโดยใช้แพคเกจนี้
    st1 = Untitled.Student('Alberto','Einsteino')
    print(st1)

    st2 = Student('Steven','Joops')
    print(st2)

    stp1 = SpecialStudent('Baron','Zemo','Zeop')
    print(stp1)

    teacher1 = Teacher('Alana Hayes')
    print(teacher1)
    
    '''

if __name__=='__main__':
    st1 = untitleoop.Untitled.Student('Alberto','Einsteino')
    print(st1)

    st2 = Student('Steven','Joops')
    print(st2)

    stp1 = SpecialStudent('Baron','Zemo','Zeop')
    print(stp1)

    teacher1 = Teacher('Alana Hayes')
    print(teacher1)